package models

import (
	"hongze/hongze_cygx/utils"
	"rdluck_tools/orm"
	"strconv"
	"time"
)

type IndustrialManagementRep struct {
	IndustryName      string `description:"产业名称"`
	ChartPermissionId int    `description:"权限id"`
	RecommendedIndex  int    `description:"推荐指数"`
	LayoutTime        string `description:"布局时间"`
	ArticleReadNum    int    `description:"文章阅读数量"`
}

type IndustrialManagementCount struct {
	IndustrialManagementId int `orm:"column(industrial_management_id);pk" description:"产业id"`
}

//获取产业置顶数量分类列表
func GetIndustrialManagemenCountTop(sqlChartPermissionId string, uid int, condition string) (items []*IndustrialManagementCount, err error) {
	o := orm.NewOrm()
	sql := `SELECT
			man_g.industrial_management_id 
			FROM
			cygx_industrial_article_group_management AS man_g
			INNER JOIN cygx_industrial_management as man ON man.industrial_management_id = man_g.industrial_management_id
			WHERE 1=1 ` + sqlChartPermissionId + `
			AND man_g.industrial_management_id IN ( SELECT industrial_management_id FROM cygx_industry_top WHERE user_id = ? ) ` + condition + `
			GROUP BY
			man_g.industrial_management_id`
	_, err = o.Raw(sql, uid).QueryRows(&items)
	return
}

//获取产业不置顶数量
func GetIndustrialManagemenCountNoTop(sqlChartPermissionId string, uid int, condition string) (items []*IndustrialManagementCount, err error) {
	o := orm.NewOrm()
	sql := `SELECT
			man_g.industrial_management_id 
			FROM
			cygx_industrial_article_group_management AS man_g
			INNER JOIN cygx_industrial_management as man ON man.industrial_management_id = man_g.industrial_management_id
			WHERE 1=1 ` + sqlChartPermissionId + `
			AND man_g.industrial_management_id NOT IN ( SELECT industrial_management_id FROM cygx_industry_top WHERE user_id = ? ) ` + condition + `
			GROUP BY
			man_g.industrial_management_id`
	_, err = o.Raw(sql, uid).QueryRows(&items)
	return
}

//产业列表
func GetIndustrialManagementAll(uid int, condition, orderSrt string, startSize, pageSize int) (items []*IndustrialManagement, err error) {
	o := orm.NewOrm()
	sql := `SELECT
			man.*,
            MAX( art.publish_date ) AS update_time ,(
			SELECT COUNT( 1 ) FROM cygx_article_history_record AS rec WHERE rec.user_id = ` + strconv.Itoa(uid) + ` AND rec.article_id = art.article_id ) AS readnum ,
		    (SELECT COUNT( 1 )  FROM cygx_industry_fllow AS f WHERE f.user_id = ` + strconv.Itoa(uid) + ` AND f.industrial_management_id = man.industrial_management_id AND f.type = 1) AS is_follow
			FROM
			cygx_industrial_management AS man
			INNER JOIN cygx_report_mapping AS re ON re.chart_permission_id = man.chart_permission_id
			INNER JOIN cygx_industrial_article_group_management AS man_g ON man_g.industrial_management_id = man.industrial_management_id
			INNER JOIN cygx_article AS art ON art.article_id = man_g.article_id 
			WHERE 1= 1
			AND re.report_type = 2 
			AND art.is_report = 1
			AND art.is_class = 1 ` + condition + `
			GROUP BY
			man.industry_name 
			ORDER BY ` + orderSrt + ` LIMIT ?,?`
	//AND man.industrial_management_id NOT IN ( SELECT industrial_management_id FROM cygx_industry_top WHERE user_id = ` + strconv.Itoa(uid) + ` )
	_, err = o.Raw(sql, startSize, pageSize).QueryRows(&items)
	return
}

//产业列表
func GetIndustrialManagementAllCount(condition string) (count int, err error) {
	o := orm.NewOrm()
	sql := `SELECT
			COUNT(*) as count 
		FROM
			(SELECT
			COUNT(*) 
		FROM
			cygx_industrial_management AS man
			INNER JOIN cygx_report_mapping AS re ON re.chart_permission_id = man.chart_permission_id
			INNER JOIN cygx_industrial_article_group_management AS man_g ON man_g.industrial_management_id = man.industrial_management_id
			INNER JOIN cygx_article AS art ON art.article_id = man_g.article_id 
		WHERE
			1 = 1 
			AND re.report_type = 2 
			AND art.is_report = 1 
			AND art.is_class = 1 ` + condition + ` GROUP BY man.industrial_management_id) AS num `
	err = o.Raw(sql).QueryRow(&count)
	return
}

//产业列表 -置顶
func GetIndustrialManagementTopAll(uid int, condition string, startSize, pageSize int) (items []*IndustrialManagement, err error) {
	o := orm.NewOrm()
	sql := `SELECT
			man.*
			FROM
			cygx_industrial_management AS man
            INNER  JOIN cygx_industry_top as top ON man.industrial_management_id = top.industrial_management_id 
			INNER JOIN cygx_report_mapping AS re ON re.chart_permission_id = man.chart_permission_id
			INNER JOIN cygx_industrial_article_group_management AS man_g ON man_g.industrial_management_id = man.industrial_management_id
			INNER JOIN cygx_article AS art ON art.article_id = man_g.article_id 
			WHERE 1=1
	
			AND top.user_id = ` + strconv.Itoa(uid) + `
			AND re.report_type = 2 
			AND art.is_report = 1
			AND art.is_class = 1 ` + condition + `
			GROUP BY
			man.industry_name 
			ORDER BY
			top.create_time DESC 	LIMIT ?,?`
	_, err = o.Raw(sql, startSize, pageSize).QueryRows(&items)
	return
}

//标的列表
func GetIndustrialSubjectAll(IndustrialManagementId int) (items []*IndustrialSubject, err error) {
	o := orm.NewOrm()
	sql := `SELECT * FROM cygx_industrial_subject WHERE industrial_management_id = ? `
	_, err = o.Raw(sql, IndustrialManagementId).QueryRows(&items)
	return
}

//分析师列表
func GetIndustrialAnalystAll(IndustrialManagementId int) (items []*IndustrialAnalyst, err error) {
	o := orm.NewOrm()
	sql := `SELECT * FROM cygx_industrial_analyst where industrial_management_id = ? `
	_, err = o.Raw(sql, IndustrialManagementId).QueryRows(&items)
	return
}

//获取产业数量
func GetIndustrialManagementCount(IndustrialManagementId int) (count int, err error) {
	sqlCount := ` SELECT COUNT(1) AS count  FROM cygx_industrial_management WHERE industrial_management_id=? `
	o := orm.NewOrm()
	err = o.Raw(sqlCount, IndustrialManagementId).QueryRow(&count)
	return
}

func GetIndustrialManagementDetail(industrialManagementId int) (items *IndustrialManagementRep, err error) {
	o := orm.NewOrm()
	sql := `SELECT * FROM cygx_industrial_management WHERE industrial_management_id = ?`
	err = o.Raw(sql, industrialManagementId).QueryRow(&items)
	return
}

//获取该产业下最新的文章详情
func GetIndustrialNewArticleDetail(industrialManagementId int) (item *ArticleDetail, err error) {
	o := orm.NewOrm()
	sql := `SELECT
	* 
FROM
	cygx_article 
WHERE
	article_id IN ( SELECT article_id FROM cygx_industrial_article_group_management WHERE industrial_management_id = ? ) 
ORDER BY
	publish_date DESC 
	LIMIT 0,1`
	err = o.Raw(sql, industrialManagementId).QueryRow(&item)
	return
}

//修改产业是否属于新标签
func UpdateIndustrialIsNewLabel() (err error) {
	o := orm.NewOrm()
	resultTime := time.Now().AddDate(0, -2, 0).Format(utils.FormatDateTime)
	var condition string
	condition += ` AND is_hand_new_label = 0 AND  create_time < ` + "'" + resultTime + "'"
	msql := " UPDATE cygx_industrial_management SET is_new_label = 0 WHERE 1 = 1 " + condition
	_, err = o.Raw(msql).Exec()
	return
}

type IndustrialManagementId struct {
	IndustrialManagementId string `description:"产业Id"`
}

//获取归类产业报告数量大于10的
func GetIndustrialMorethan10() (items []*IndustrialManagementId, err error) {
	o := orm.NewOrm()
	sql := `SELECT * FROM
			( SELECT industrial_management_id, COUNT( 1 ) AS ca FROM cygx_industrial_article_group_management GROUP BY industrial_management_id ) AS na 
			WHERE ca > 10 `
	_, err = o.Raw(sql).QueryRows(&items)
	return
}

//修改产业是否属于深度标签
func UpdateIndustrialIsDeepLabel(idStr string) (err error) {
	o := orm.NewOrm()
	msql := `UPDATE cygx_industrial_management
	SET is_deep_label = 1
	WHERE
	industrial_management_id IN (
		SELECT
	industrial_management_id
	FROM
	cygx_industrial_article_group_management AS a
	INNER JOIN cygx_article AS b ON b.id = a.cygx_article_id
	WHERE
	1 = 1
	AND b.match_type_name = '行业深度'
	AND a.industrial_management_id IN ( ` + idStr + `)
	AND is_hand_deep_label = 0
	GROUP BY
	a.industrial_management_id)`
	_, err = o.Raw(msql).Exec()
	return
}

type IndustrialManagementIdInt struct {
	IndustrialManagementId int    `description:"产业Id"`
	IndustryName           string `description:"产业名称"`
	SubjectName            string `description:"标的名称"`
	ArticleId              int    `description:"文章ID"`
}

type IndustrialManagementIdInts struct {
	IndustrialManagementId  int    `description:"产业Id"`
	IndustryName            string `description:"产业名称"`
	SubjectNames            string `description:"标的名称"`
	ArticleId               int    `description:"文章ID"`
	IndustrialAndSubjectIds string `description:"关联标的以及产业ID"`
}

type IndustrialManagementIdName struct {
	DepartmentId int    `description:"作者ID"`
	ArticleId    int    `description:"文章id"`
	IndustryName string `description:"产业名称"`
	SubjectName  string `description:"标的名称"`
	IsReport     string `description:"1观点，0纪要"`
}

//获取归类产业报告数量大于10的
func GetIndustrialManagementIds() (items []*IndustrialManagementIdInt, err error) {
	o := orm.NewOrm()
	//sql := `SELECT a.industrial_management_id FROM
	//		cygx_industrial_management AS a
	//		INNER JOIN cygx_industrial_subject as b ON b.industrial_management_id=a.industrial_management_id
	//		WHERE b.industrial_subject_id > 0
	//		GROUP BY a.industrial_management_id `

	sql := `SELECT industrial_management_id,industry_name FROM cygx_industrial_management `
	_, err = o.Raw(sql).QueryRows(&items)
	return
}

func GetcygxIndustrialSubject(industrialManagementId int) (items []*IndustrialSubject, err error) {
	o := orm.NewOrm()
	sql := `SELECT subject_name FROM cygx_industrial_subject  WHERE industrial_management_id = ?`
	_, err = o.Raw(sql, industrialManagementId).QueryRows(&items)
	return
}

func UpdateIndustrialManagementSubjectNames(nameStr string, industrialManagementId int) (err error) {
	o := orm.NewOrm()
	sql := `UPDATE cygx_industrial_management SET subject_names = ? WHERE industrial_management_id = ?`
	_, err = o.Raw(sql, nameStr, industrialManagementId).Exec()
	return
}

// 处理每个产业下所关联的文章的阅读量  start
func IndustrialManagementAll() (items []*IndustrialManagement, err error) {
	o := orm.NewOrm()
	sql := `SELECT * FROM cygx_industrial_management `
	_, err = o.Raw(sql).QueryRows(&items)
	return
}

func GetIndustrialManagementArtCount(industrialManagementId int) (count int, err error) {
	sqlCount := ` SELECT COUNT(1) AS count  
	 			FROM  cygx_article_history_record AS h
				INNER JOIN cygx_industrial_article_group_management as mg ON  mg.article_id = h.article_id
				WHERE mg.industrial_management_id = ?`
	o := orm.NewOrm()
	err = o.Raw(sqlCount, industrialManagementId).QueryRow(&count)
	return
}

func UpdateIndustrialManagementArtReadNum(num, industrialManagementId int) (err error) {
	o := orm.NewOrm()
	sql := `UPDATE cygx_industrial_management SET article_read_num = ? WHERE industrial_management_id = ?`
	_, err = o.Raw(sql, num, industrialManagementId).Exec()
	return
}

//获取产业下阅读数量第三的产业详情
func GetIndustrialManagementHot3(chartPermissionId int) (item *IndustrialManagementRep, err error) {
	o := orm.NewOrm()
	sql := `SELECT * FROM cygx_industrial_management WHERE chart_permission_id = ? ORDER BY article_read_num DESC LIMIT 2,1`
	err = o.Raw(sql, chartPermissionId).QueryRow(&item)
	return
}

//获取产业关联标的的数量
func GetIndustrialManagementSubjectCount(industrialManagementId int) (count int, err error) {
	sqlCount := ` SELECT COUNT(1) AS count FROM
				cygx_industrial_subject AS s 
				INNER JOIN cygx_industrial_article_group_subject as sg ON sg.industrial_subject_id = s.industrial_subject_id
				INNER JOIN cygx_article as a ON a.article_id = sg.article_id
				WHERE a.industrial_management_id = ?
				AND a.publish_status = 1`
	o := orm.NewOrm()
	err = o.Raw(sqlCount, industrialManagementId).QueryRow(&count)
	return
}

//获取产业关联标的列表
func GetIndustrialManagementSubjectList(articleId int) (items []*IndustrialSubject, err error) {
	o := orm.NewOrm()
	sql := `SELECT
	s.subject_name 
FROM
	cygx_industrial_subject AS s
	INNER JOIN cygx_industrial_article_group_subject AS sg ON sg.industrial_subject_id = s.industrial_subject_id
	INNER JOIN cygx_article AS a 
WHERE
	sg.article_id = ? 
	AND a.publish_status = 1 
GROUP BY
	s.industrial_subject_id 
ORDER BY
	sg.create_time DESC 
	LIMIT 4`
	_, err = o.Raw(sql, articleId).QueryRows(&items)
	return
}
